Getting Started 🦥
==================

This page includes example 🚀 notebooks intended for new users 👶 of
PlasmaPy ✨, including notebooks that introduce `astropy.units` and
`plasmapy.particles`.

.. nbgallery::

   notebooks/getting_started/units
   notebooks/getting_started/particles
